@@ -76,6 +76,7 @@ def step_cmd(inpre, outpre, physics):
         ' inpre={inpre}'
         .format(inpre=inpre, outpre=outpre, **physics)
         )
+    if 'mingenjetpt' in physics: cmd += ' mingenjetpt={0:.1f}'.format(physics['mingenjetpt'])
     if 'boost' in physics: cmd += ' boost={0:.0f}'.format(physics['boost'])
     if 'max_events' in physics: cmd += ' maxEvents={0}'.format(physics['max_events'])
     return cmd
@@ -156,7 +157,7 @@ class CMSSW(qondor.CMSSW):
         for inpre, outpre in zip(inpres, outpres):
             expected_outfile = self.run_step(
                 inpre, outpre, physics,
-                n_attempts = 3 if 'RECO' in outpre else 1
+                n_attempts = 3 if ('RECO' in outpre or 'DIGI' in outpre) else 1
                 )
         return expected_outfile
     
